Page
Library
Module
Module type
Parameter
Class
Class type
Note.LogrSourceEvent and signal changes loggers.
Loggers are the output interface of the reactive system. They allow external entities to observe event occurrences and signal changes.
The type for observing changes of type 'a.
app f v is the observation that result from applying the changes of f to the ones of v.
The type for loggers.
create ~now o is a logger that observes changes to o. If now is true (default) logs at least one observation before the call returns.
destroy l destroys log l this ensure that l's does not observe any change again. The underlying observed events or signals also stop updating, unless they are observed by another logger.
may_hold l holds logger Some l to ensure it does not get garbage collected. Does nothing on None.